import zeep

# Webová služba pro práci s časopisy a fakturami
class Journal:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Journal.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Journal.asmx?wsdl')

    # Nastavit ID_Document se zipem
    def JournalCopyOrderUpdateDocument(self, ID_Login, ID, DateSent, ID_Journal, ID_Document, DisplayName=None, Journal=None, Message=None):
        return self._client.service.JournalCopyOrderUpdateDocument({"ID_Login": ID_Login, "ID": ID, "DateSent": DateSent, "ID_Journal": ID_Journal, "ID_Document": ID_Document, "DisplayName": DisplayName, "Journal": Journal, "Message": Message})

    # Načíst seznam výtisků časopisu v balíku
    def JournalCopyPackAll(self, ID_Login, JournalCopyRoot=None):
        return self._client.service.JournalCopyPackAll({"ID_Login": ID_Login, "JournalCopyRoot": JournalCopyRoot})

    # Načíst seznam fakturovaných časopisů
    def JournalCopySentAllIInvoiceSummaryVat(self, ID_Login, ID_Invoice):
        return self._client.service.JournalCopySentAllIInvoiceSummaryVat({"ID_Login": ID_Login, "ID_Invoice": ID_Invoice})

    # Načíst detail výtisku časopisu pro vrácený časopis
    def JournalCopySentDetailReturned(self, ID_Login, ID, IsPackage):
        return self._client.service.JournalCopySentDetailReturned({"ID_Login": ID_Login, "ID": ID, "IsPackage": IsPackage})

    # Načíst seznam typů doručení
    def JournalDeliveryTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.JournalDeliveryTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam způsobů odběru balíčků pro nováčky
    def JournalNoviceAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.JournalNoviceAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Upravi/vlozi odpoved na rovera
    def RoverJournalUpdate(self, ID_Login, ID, ID_Person, DateCreated, ID_RoverJournalYear, Person=None, ID_RoverJournalType=None, RoverJournalType=None):
        return self._client.service.RoverJournalUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "DateCreated": DateCreated, "ID_RoverJournalYear": ID_RoverJournalYear, "Person": Person, "ID_RoverJournalType": ID_RoverJournalType, "RoverJournalType": RoverJournalType})

    # Upozornění na osoby v roverském věku
    def RoverJournalWarning(self, ID_Login):
        return self._client.service.RoverJournalWarning({"ID_Login": ID_Login})

    # Načíst aktuální rok pro rovera
    def RoverJournalYearDetail(self, ID_Login):
        return self._client.service.RoverJournalYearDetail({"ID_Login": ID_Login})

    # Typ odpovědi
    def RoverJournalTypeAll(self, ID_Login, DisplayName=None, ID=None):
        return self._client.service.RoverJournalTypeAll({"ID_Login": ID_Login, "DisplayName": DisplayName, "ID": ID})

    # Změnit data odeslání u vybraných záznamů
    def JournalCopyVipUpdateDateSentId(self, ID_Login, DateSent, ID=None):
        return self._client.service.JournalCopyVipUpdateDateSentId({"ID_Login": ID_Login, "DateSent": DateSent, "ID": ID})

    # Načíst seznam objednávek časopisu
    def JournalCopyOrderAll(self, ID_Login, ID, ID_Journal):
        return self._client.service.JournalCopyOrderAll({"ID_Login": ID_Login, "ID": ID, "ID_Journal": ID_Journal})

    # Načíst detail objednávky časopisu
    def JournalCopyOrderDetail(self, ID_Login, ID):
        return self._client.service.JournalCopyOrderDetail({"ID_Login": ID_Login, "ID": ID})

    def JournalCopyOrderItemAll(self, ID_Login, ID_JournalCopyOrder, ID, DisplayName=None):
        return self._client.service.JournalCopyOrderItemAll({"ID_Login": ID_Login, "ID_JournalCopyOrder": ID_JournalCopyOrder, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail položky objednávky časopisů
    def JournalCopyOrderItemDetail(self, ID_Login, ID):
        return self._client.service.JournalCopyOrderItemDetail({"ID_Login": ID_Login, "ID": ID})

    # Odeslat připravené zprávy
    def JournalCopyOrderUpdateSendMessage(self, ID_Login, ID, DateSent, ID_Journal, ID_Document, DisplayName=None, Journal=None, Message=None):
        return self._client.service.JournalCopyOrderUpdateSendMessage({"ID_Login": ID_Login, "ID": ID, "DateSent": DateSent, "ID_Journal": ID_Journal, "ID_Document": ID_Document, "DisplayName": DisplayName, "Journal": Journal, "Message": Message})

    # Vygenerovat soubory s rozesílkou a odeslat IZS
    def JournalCopyUpdateSendMessage(self, ID_Login, DateSent, SendMessage, OrderVIP):
        return self._client.service.JournalCopyUpdateSendMessage({"ID_Login": ID_Login, "DateSent": DateSent, "SendMessage": SendMessage, "OrderVIP": OrderVIP})

    # Načíst seznam VIP časopisů
    def JournalCopyVipAll(self, ID_Login, ID, ID_Person, ID_Journal, ID_JournalAttachment, ID_PersonCreate, DateSent, Person=None):
        return self._client.service.JournalCopyVipAll({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Journal": ID_Journal, "ID_JournalAttachment": ID_JournalAttachment, "ID_PersonCreate": ID_PersonCreate, "DateSent": DateSent, "Person": Person})

    # Smazat VIP časopis
    def JournalCopyVipDelete(self, ID_Login, ID):
        return self._client.service.JournalCopyVipDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail VIP časopisu
    def JournalCopyVipDetail(self, ID_Login, ID):
        return self._client.service.JournalCopyVipDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit VIP časopis
    def JournalCopyVipInsert(self, ID_Login, ID, ID_Person, ID_Journal, ID_JournalAttachment, DateSent, ID_PersonCreate, ValidTo, Person=None, Journal=None, JournalAttachment=None, PersonCreate=None, FirstLine=None, Street=None, City=None, Postcode=None):
        return self._client.service.JournalCopyVipInsert({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Journal": ID_Journal, "ID_JournalAttachment": ID_JournalAttachment, "DateSent": DateSent, "ID_PersonCreate": ID_PersonCreate, "ValidTo": ValidTo, "Person": Person, "Journal": Journal, "JournalAttachment": JournalAttachment, "PersonCreate": PersonCreate, "FirstLine": FirstLine, "Street": Street, "City": City, "Postcode": Postcode})

    # Upravit VIP časopis
    def JournalCopyVipUpdate(self, ID_Login, ID, ID_Person, ID_Journal, ID_JournalAttachment, DateSent, ID_PersonCreate, ValidTo, Person=None, Journal=None, JournalAttachment=None, PersonCreate=None, FirstLine=None, Street=None, City=None, Postcode=None):
        return self._client.service.JournalCopyVipUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Journal": ID_Journal, "ID_JournalAttachment": ID_JournalAttachment, "DateSent": DateSent, "ID_PersonCreate": ID_PersonCreate, "ValidTo": ValidTo, "Person": Person, "Journal": Journal, "JournalAttachment": JournalAttachment, "PersonCreate": PersonCreate, "FirstLine": FirstLine, "Street": Street, "City": City, "Postcode": Postcode})

    # Upravit VIP časopis
    def JournalCopyVipUpdateDateSent(self, ID_Login, DateSentOld, DateSentNew):
        return self._client.service.JournalCopyVipUpdateDateSent({"ID_Login": ID_Login, "DateSentOld": DateSentOld, "DateSentNew": DateSentNew})

    # Zjistit zda osoba odebírá časopis
    def PersonJournalDetailExists(self, ID_Login, ID_Person, ID_Journal):
        return self._client.service.PersonJournalDetailExists({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_Journal": ID_Journal})

    # Upozornění na změnu časopisů zdarma
    def PersonJournalWarningFree(self, ID_Login):
        return self._client.service.PersonJournalWarningFree({"ID_Login": ID_Login})

    # Načíst fakturu v pdf
    def InvoiceDetailPdf(self, ID_Login, ID):
        return self._client.service.InvoiceDetailPdf({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam faktur v xml
    def InvoiceAllXml(self, ID_Login, ID, DateGeneratingFrom, DateGeneratingTo, ID_InvoiceState=None):
        return self._client.service.InvoiceAllXml({"ID_Login": ID_Login, "ID": ID, "DateGeneratingFrom": DateGeneratingFrom, "DateGeneratingTo": DateGeneratingTo, "ID_InvoiceState": ID_InvoiceState})

    # Načíst seznam faktur v xml zabalenych do zipu
    def InvoiceAllZip(self, ID_Login, DateGeneratingFrom, DateGeneratingTo, ID_InvoiceState=None):
        return self._client.service.InvoiceAllZip({"ID_Login": ID_Login, "DateGeneratingFrom": DateGeneratingFrom, "DateGeneratingTo": DateGeneratingTo, "ID_InvoiceState": ID_InvoiceState})

    # Smazat připravenou rozesílku
    def JournalCopyDeleteOne(self, ID_Login, ID_Journal, DateSent, DisplayName=None):
        return self._client.service.JournalCopyDeleteOne({"ID_Login": ID_Login, "ID_Journal": ID_Journal, "DateSent": DateSent, "DisplayName": DisplayName})

    # Změnit časopisy Zdarma dle věkové kategorie
    def PersonJournalChangeFree(self, ID_Login):
        return self._client.service.PersonJournalChangeFree({"ID_Login": ID_Login})

    # Načíst seznam odeslaných výtisků časopisů
    def JournalCopySentAll(self, ID_Login, ID_Person, ID_Unit, ID_Journal, ID_JournalCopySent, DisplayName=None):
        return self._client.service.JournalCopySentAll({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Journal": ID_Journal, "ID_JournalCopySent": ID_JournalCopySent, "DisplayName": DisplayName})

    # Načíst seznam Stavů faktury
    def InvoiceStateAll(self, ID_Login, DisplayName=None):
        return self._client.service.InvoiceStateAll({"ID_Login": ID_Login, "DisplayName": DisplayName})

    # Načíst detail odeslaného výtisku časopisu
    def JournalCopySentDetail(self, ID_Login, ID):
        return self._client.service.JournalCopySentDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam vrácených časopisů jednotky
    def JournalReturnedAll(self, ID_Login, ID_Unit, ID_JournalCopySent, ID_JournalReturnedReason=None):
        return self._client.service.JournalReturnedAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID_JournalCopySent": ID_JournalCopySent, "ID_JournalReturnedReason": ID_JournalReturnedReason})

    # Založit vrácený časopis
    def JournalReturnedInsert(self, ID_Login, ID_JournalCopySent, DateCreate, OnlyValidate, JournalCopySent=None, ID_JournalReturnedReason=None, Note=None):
        return self._client.service.JournalReturnedInsert({"ID_Login": ID_Login, "ID_JournalCopySent": ID_JournalCopySent, "DateCreate": DateCreate, "OnlyValidate": OnlyValidate, "JournalCopySent": JournalCopySent, "ID_JournalReturnedReason": ID_JournalReturnedReason, "Note": Note})

    # Načíst seznam důvodů nedoručitelnosti
    def JournalReturnedReasonAll(self, ID_Login, IsPackage, DisplayName=None):
        return self._client.service.JournalReturnedReasonAll({"ID_Login": ID_Login, "IsPackage": IsPackage, "DisplayName": DisplayName})

    # Načte počet zbývajících příloh zdarma
    def PersonJournalFreeAttachments(self, ID_Login, ID_Unit):
        return self._client.service.PersonJournalFreeAttachments({"ID_Login": ID_Login, "ID_Unit": ID_Unit})

    # Načíst seznam faktur podle stavu
    def InvoiceAllInvoiceState(self, ID_Login, ID_InvoiceState=None):
        return self._client.service.InvoiceAllInvoiceState({"ID_Login": ID_Login, "ID_InvoiceState": ID_InvoiceState})

    # Ukončit ročník
    def JournalCopyUpdateCloseYear(self, ID_Login):
        return self._client.service.JournalCopyUpdateCloseYear({"ID_Login": ID_Login})

    # Načíst seznam faktur jednotky
    def InvoiceAllUnit(self, ID_Login, ID_Unit, DateGeneratingFrom, DateGeneratingTo, DisplayName=None, ID_InvoiceState=None):
        return self._client.service.InvoiceAllUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "DateGeneratingFrom": DateGeneratingFrom, "DateGeneratingTo": DateGeneratingTo, "DisplayName": DisplayName, "ID_InvoiceState": ID_InvoiceState})

    # Upravit fakturu
    def InvoiceUpdate(self, ID_Login, ID, ID_Unit, IsVatPayer, DateGenerating, Maturity, Sequence, ID_Person, TotalPrice, TotalPriceWithVat, Price, PriceBase, PriceFirst, PriceSecond, VatBase, VatFirst, VatSecond, ID_InvoiceGroup, DateTaxableSupply, DisplayName=None, Unit=None, Street=None, City=None, Postcode=None, State=None, StateCode=None, IC=None, DIC=None, ID_InvoiceState=None, InvoiceState=None, Person=None, QRCodeString=None, InvoiceGroupContractorIC=None, InvoiceGroupContractorDIC=None, InvoiceGroupContractorPhone=None, InvoiceGroupContractorEmail=None, InvoiceGroupWeb=None, InvoiceGroupFileReference=None, InvoiceGroupBankAccount=None, InvoiceGroupBankCode=None, InvoiceGroupBank=None, PaymentType=None, InvoiceGroupContractor=None, InvoiceGroupContractorAddress=None):
        return self._client.service.InvoiceUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "IsVatPayer": IsVatPayer, "DateGenerating": DateGenerating, "Maturity": Maturity, "Sequence": Sequence, "ID_Person": ID_Person, "TotalPrice": TotalPrice, "TotalPriceWithVat": TotalPriceWithVat, "Price": Price, "PriceBase": PriceBase, "PriceFirst": PriceFirst, "PriceSecond": PriceSecond, "VatBase": VatBase, "VatFirst": VatFirst, "VatSecond": VatSecond, "ID_InvoiceGroup": ID_InvoiceGroup, "DateTaxableSupply": DateTaxableSupply, "DisplayName": DisplayName, "Unit": Unit, "Street": Street, "City": City, "Postcode": Postcode, "State": State, "StateCode": StateCode, "IC": IC, "DIC": DIC, "ID_InvoiceState": ID_InvoiceState, "InvoiceState": InvoiceState, "Person": Person, "QRCodeString": QRCodeString, "InvoiceGroupContractorIC": InvoiceGroupContractorIC, "InvoiceGroupContractorDIC": InvoiceGroupContractorDIC, "InvoiceGroupContractorPhone": InvoiceGroupContractorPhone, "InvoiceGroupContractorEmail": InvoiceGroupContractorEmail, "InvoiceGroupWeb": InvoiceGroupWeb, "InvoiceGroupFileReference": InvoiceGroupFileReference, "InvoiceGroupBankAccount": InvoiceGroupBankAccount, "InvoiceGroupBankCode": InvoiceGroupBankCode, "InvoiceGroupBank": InvoiceGroupBank, "PaymentType": PaymentType, "InvoiceGroupContractor": InvoiceGroupContractor, "InvoiceGroupContractorAddress": InvoiceGroupContractorAddress})

    # Načíst seznam fakturovaných časopisů
    def JournalCopySentAllInvoice(self, ID_Login, ID_Invoice):
        return self._client.service.JournalCopySentAllInvoice({"ID_Login": ID_Login, "ID_Invoice": ID_Invoice})

    # Načíst seznam faktur
    def InvoiceAll(self, ID_Login, ID_Unit, DateGeneratingFrom, DateGeneratingTo, DisplayName=None, ID_InvoiceState=None):
        return self._client.service.InvoiceAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "DateGeneratingFrom": DateGeneratingFrom, "DateGeneratingTo": DateGeneratingTo, "DisplayName": DisplayName, "ID_InvoiceState": ID_InvoiceState})

    # Načíst detail faktury
    def InvoiceDetail(self, ID_Login, ID):
        return self._client.service.InvoiceDetail({"ID_Login": ID_Login, "ID": ID})

    # Vygenerovat faktury za rozeslané a dosud neuhrazené časopisy
    def InvoiceInsert(self, ID_Login, AllUnits, ID_Unit, DateGenerating, Maturity):
        return self._client.service.InvoiceInsert({"ID_Login": ID_Login, "AllUnits": AllUnits, "ID_Unit": ID_Unit, "DateGenerating": DateGenerating, "Maturity": Maturity})

    # Číselník datumů odeslání připravených zásilek
    def JournalCopyALLDateSent(self, ID_Login):
        return self._client.service.JournalCopyALLDateSent({"ID_Login": ID_Login})

    # Přidat speciální zásilku
    def JournalCopyInsertSpecial(self, ID_Login, DateSent, IsInsert, FunctionTypeNegation, RoverJournal, AlignmentTypeNegation, AgeFrom, AgeTo, HasPreparedJournal, JournalParent, DisplayName=None, Note=None, ID_FunctionTypeArray=None, ID_SexUnit=None, ID_TroopArtArray=None, ID_AlignmentTypeArray=None, ID_MembershipCategoryArray=None, ID_MembershipCategoryPersonNumberArray=None, ID_PersonNumberArray=None, ID_JournalArray=None, IsAdultStem=None):
        return self._client.service.JournalCopyInsertSpecial({"ID_Login": ID_Login, "DateSent": DateSent, "IsInsert": IsInsert, "FunctionTypeNegation": FunctionTypeNegation, "RoverJournal": RoverJournal, "AlignmentTypeNegation": AlignmentTypeNegation, "AgeFrom": AgeFrom, "AgeTo": AgeTo, "HasPreparedJournal": HasPreparedJournal, "JournalParent": JournalParent, "DisplayName": DisplayName, "Note": Note, "ID_FunctionTypeArray": ID_FunctionTypeArray, "ID_SexUnit": ID_SexUnit, "ID_TroopArtArray": ID_TroopArtArray, "ID_AlignmentTypeArray": ID_AlignmentTypeArray, "ID_MembershipCategoryArray": ID_MembershipCategoryArray, "ID_MembershipCategoryPersonNumberArray": ID_MembershipCategoryPersonNumberArray, "ID_PersonNumberArray": ID_PersonNumberArray, "ID_JournalArray": ID_JournalArray, "IsAdultStem": IsAdultStem})

    # Přehled titulů připravených k rozesílce
    def JournalCopyAllSummary(self, ID_Login):
        return self._client.service.JournalCopyAllSummary({"ID_Login": ID_Login})

    # Smazat připravenou rozesílku
    def JournalCopyDelete(self, ID_Login):
        return self._client.service.JournalCopyDelete({"ID_Login": ID_Login})

    # Přidat časopis do rozesílky
    def JournalCopyInsert(self, ID_Login, ID_Journal, DateSent, Price, ID_VatRate, DisplayName=None):
        return self._client.service.JournalCopyInsert({"ID_Login": ID_Login, "ID_Journal": ID_Journal, "DateSent": DateSent, "Price": Price, "ID_VatRate": ID_VatRate, "DisplayName": DisplayName})

    # Generovat seznam adres k rozesílce
    def JournalCopyUpdateGenerate(self, ID_Login, DateSent, CreateOrder, OrderVIP):
        return self._client.service.JournalCopyUpdateGenerate({"ID_Login": ID_Login, "DateSent": DateSent, "CreateOrder": CreateOrder, "OrderVIP": OrderVIP})

    # Nastavit připravenou zásilku jako odeslanou
    def JournalCopyUpdateSent(self, ID_Login):
        return self._client.service.JournalCopyUpdateSent({"ID_Login": ID_Login})

    # Načíst detail titulu časopisu
    def JournalDetail(self, ID_Login, ID):
        return self._client.service.JournalDetail({"ID_Login": ID_Login, "ID": ID})

    # Objednat přílohu zdarma
    def PersonJournalInsertUnit(self, ID_Login, ID_Person, ValidFrom, ValidTo, ID, ID_Unit, ID_Journal, IsFree, IsAuthorized, IsPaid, IsNovice, Person=None, Unit=None, Journal=None, ID_JournalType=None, JournalType=None, ID_JournalDeliveryType=None, JournalDeliveryType=None, Key=None):
        return self._client.service.PersonJournalInsertUnit({"ID_Login": ID_Login, "ID_Person": ID_Person, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "ID": ID, "ID_Unit": ID_Unit, "ID_Journal": ID_Journal, "IsFree": IsFree, "IsAuthorized": IsAuthorized, "IsPaid": IsPaid, "IsNovice": IsNovice, "Person": Person, "Unit": Unit, "Journal": Journal, "ID_JournalType": ID_JournalType, "JournalType": JournalType, "ID_JournalDeliveryType": ID_JournalDeliveryType, "JournalDeliveryType": JournalDeliveryType, "Key": Key})

    # Načíst seznam objednaných časopisů
    def PersonJournalAllUnit(self, ID_Login, ID_Unit, ID_Person, ID_Journal, ShowHistory, IncludeChild, IncludeAttachmentCount, IsValid):
        return self._client.service.PersonJournalAllUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID_Person": ID_Person, "ID_Journal": ID_Journal, "ShowHistory": ShowHistory, "IncludeChild": IncludeChild, "IncludeAttachmentCount": IncludeAttachmentCount, "IsValid": IsValid})

    # Načíst seznam titulů časopisů
    def JournalAll(self, ID_Login, HideAttachment, DisplayName=None, ID_JournalType=None):
        return self._client.service.JournalAll({"ID_Login": ID_Login, "HideAttachment": HideAttachment, "DisplayName": DisplayName, "ID_JournalType": ID_JournalType})

    # Načíst seznam výtisků časopisů
    def JournalCopyAll(self, ID_Login, ID_Person, ID_Unit, ID_Journal, ID_JournalCopy, DisplayName=None):
        return self._client.service.JournalCopyAll({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Journal": ID_Journal, "ID_JournalCopy": ID_JournalCopy, "DisplayName": DisplayName})

    # Načíst seznam objednaných časopisů
    def PersonJournalAll(self, ID_Login, ID_Person, ID_Unit, ID_Journal, ShowHistory, IsValid):
        return self._client.service.PersonJournalAll({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Journal": ID_Journal, "ShowHistory": ShowHistory, "IsValid": IsValid})

    # Smazat objednaný časopis
    def PersonJournalDelete(self, ID_Login, ID, DeleteAttachment):
        return self._client.service.PersonJournalDelete({"ID_Login": ID_Login, "ID": ID, "DeleteAttachment": DeleteAttachment})

    # Načíst detail objednaného časopisu
    def PersonJournalDetail(self, ID_Login, ID):
        return self._client.service.PersonJournalDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit objednaný časopis
    def PersonJournalInsert(self, ID_Login, ID_Person, ValidFrom, ValidTo, ID, ID_Unit, ID_Journal, IsFree, IsAuthorized, IsPaid, IsNovice, Person=None, Unit=None, Journal=None, ID_JournalType=None, JournalType=None, ID_JournalDeliveryType=None, JournalDeliveryType=None, Key=None):
        return self._client.service.PersonJournalInsert({"ID_Login": ID_Login, "ID_Person": ID_Person, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "ID": ID, "ID_Unit": ID_Unit, "ID_Journal": ID_Journal, "IsFree": IsFree, "IsAuthorized": IsAuthorized, "IsPaid": IsPaid, "IsNovice": IsNovice, "Person": Person, "Unit": Unit, "Journal": Journal, "ID_JournalType": ID_JournalType, "JournalType": JournalType, "ID_JournalDeliveryType": ID_JournalDeliveryType, "JournalDeliveryType": JournalDeliveryType, "Key": Key})

    # Upravit objednaný časopis
    def PersonJournalUpdate(self, ID_Login, ID_Person, ValidFrom, ValidTo, ID, ID_Unit, ID_Journal, IsFree, IsAuthorized, IsPaid, IsNovice, Person=None, Unit=None, Journal=None, ID_JournalType=None, JournalType=None, ID_JournalDeliveryType=None, JournalDeliveryType=None, Key=None):
        return self._client.service.PersonJournalUpdate({"ID_Login": ID_Login, "ID_Person": ID_Person, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "ID": ID, "ID_Unit": ID_Unit, "ID_Journal": ID_Journal, "IsFree": IsFree, "IsAuthorized": IsAuthorized, "IsPaid": IsPaid, "IsNovice": IsNovice, "Person": Person, "Unit": Unit, "Journal": Journal, "ID_JournalType": ID_JournalType, "JournalType": JournalType, "ID_JournalDeliveryType": ID_JournalDeliveryType, "JournalDeliveryType": JournalDeliveryType, "Key": Key})




import zeep

# Webová služba pro práci s pojištěním osoby
class Insurance:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Insurance.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Insurance.asmx?wsdl')

    # Načíst seznam Částek za rok
    def AmountPersonAll(self, ID_Application, ID_Login, ID):
        return self._client.service.AmountPersonAll({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID})

    # Smazat Částku za rok
    def AmountPersonDelete(self, ID_Application, ID_Login, ID):
        return self._client.service.AmountPersonDelete({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID})

    # Načíst detail Částky za rok
    def AmountPersonDetail(self, ID_Application, ID_Login, ID, Year):
        return self._client.service.AmountPersonDetail({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID, "Year": Year})

    # Založit Částku za rok
    def AmountPersonInsert(self, ID_Login, ID, Amount, Year, Note=None):
        return self._client.service.AmountPersonInsert({"ID_Login": ID_Login, "ID": ID, "Amount": Amount, "Year": Year, "Note": Note})

    # Upravit Částku za rok
    def AmountPersonUpdate(self, ID_Login, ID, Amount, Year, Note=None):
        return self._client.service.AmountPersonUpdate({"ID_Login": ID_Login, "ID": ID, "Amount": Amount, "Year": Year, "Note": Note})

    # Načíst seznam osob pro pojištění
    def PersonAllUnit(self, ID_Login, ID_Unit, Year, ShowRegistered):
        return self._client.service.PersonAllUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "Year": Year, "ShowRegistered": ShowRegistered})

    # Načíst seznam pojištěných osob
    def PersonAllRegistration(self, ID_Login, ID_Registration):
        return self._client.service.PersonAllRegistration({"ID_Login": ID_Login, "ID_Registration": ID_Registration})

    # Načíst seznam pojištění osob
    def PersonAll(self, ID_Login, ID_Unit, ID_Function, Year, Person=None):
        return self._client.service.PersonAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID_Function": ID_Function, "Year": Year, "Person": Person})

    # Smazat pojištění osoby
    def PersonDelete(self, ID_Login, ID):
        return self._client.service.PersonDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail pojištění osoby
    def PersonDetail(self, ID_Login, ID):
        return self._client.service.PersonDetail({"ID_Login": ID_Login, "ID": ID})

    # Upravit pojištění osoby
    def PersonUpdate(self, ID_Login, ID, ID_Person, ID_Unit, ID_Function, ValidFrom, ValidTo, Amount, PersonDisplayName=None, Unit=None, RegistrationNumber=None, Note=None):
        return self._client.service.PersonUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Function": ID_Function, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "Amount": Amount, "PersonDisplayName": PersonDisplayName, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Note": Note})

    # Načíst seznam registrací, u kterých selhalo odeslání
    def RegistrationAllPostFailed(self, ID_Login, ShowRegistrationOnly):
        return self._client.service.RegistrationAllPostFailed({"ID_Login": ID_Login, "ShowRegistrationOnly": ShowRegistrationOnly})

    # Načíst detail registrace
    def RegistrationDetail(self, ID_Login, ID):
        return self._client.service.RegistrationDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit registraci
    def RegistrationInsert(self, ID_Login, ID_Unit, Year, OnlyValidate, Note=None, Persons=None):
        return self._client.service.RegistrationInsert({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "Year": Year, "OnlyValidate": OnlyValidate, "Note": Note, "Persons": Persons})

    # Upravit registraci
    def RegistrationUpdate(self, ID_Login, ID, ExternalID, ID_Unit, ID_Person, Created, Unit=None, RegistrationNumber=None, Person=None, Note=None):
        return self._client.service.RegistrationUpdate({"ID_Login": ID_Login, "ID": ID, "ExternalID": ExternalID, "ID_Unit": ID_Unit, "ID_Person": ID_Person, "Created": Created, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Person": Person, "Note": Note})




import zeep

# Webová služba pro správu obsahu (redakční systém)
class ContentManagement:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/ContentManagement.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/ContentManagement.asmx?wsdl')

    # Načíst seznam oblíbených stránek
    def FavoriteAll(self, ID_Login, ID_User, ID, ID_Page, Top, DisplayName=None):
        return self._client.service.FavoriteAll({"ID_Login": ID_Login, "ID_User": ID_User, "ID": ID, "ID_Page": ID_Page, "Top": Top, "DisplayName": DisplayName})

    # Smazat oblíbenou stránku
    def FavoriteDelete(self, ID_Login, ID):
        return self._client.service.FavoriteDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail oblíbené stránky
    def FavoriteDetail(self, ID_Login, ID, ID_Page, ID_User):
        return self._client.service.FavoriteDetail({"ID_Login": ID_Login, "ID": ID, "ID_Page": ID_Page, "ID_User": ID_User})

    # Založit oblíbenou stránku
    def FavoriteInsert(self, ID_Login, ID, ID_User, ID_Page, DateCreate, Page=None, DisplayName=None, UrlParameter=None):
        return self._client.service.FavoriteInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Page": ID_Page, "DateCreate": DateCreate, "Page": Page, "DisplayName": DisplayName, "UrlParameter": UrlParameter})

    # Upravit oblíbenou stránku
    def FavoriteUpdate(self, ID_Login, ID, ID_User, ID_Page, DateCreate, Page=None, DisplayName=None, UrlParameter=None):
        return self._client.service.FavoriteUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Page": ID_Page, "DateCreate": DateCreate, "Page": Page, "DisplayName": DisplayName, "UrlParameter": UrlParameter})

    # Vyresetovat pořadí záložek
    def TabUpdateReset(self, ID_Login, MasterPage=None):
        return self._client.service.TabUpdateReset({"ID_Login": ID_Login, "MasterPage": MasterPage})

    # Načte podřízené položky hlavního menu jako HTML
    def MenuAllSubmenuHtml(self, ID_Login, ID, BaseUrl=None):
        return self._client.service.MenuAllSubmenuHtml({"ID_Login": ID_Login, "ID": ID, "BaseUrl": BaseUrl})

    # Načte položky hlavního menu jako HTML
    def MenuAllRootHtml(self, ID_Login, BaseUrl=None):
        return self._client.service.MenuAllRootHtml({"ID_Login": ID_Login, "BaseUrl": BaseUrl})

    # Načíst detail stránky
    def PageDetail(self, ID_Login, ID, CheckPermissions, Url=None, UrlParameter=None):
        return self._client.service.PageDetail({"ID_Login": ID_Login, "ID": ID, "CheckPermissions": CheckPermissions, "Url": Url, "UrlParameter": UrlParameter})

    # Načíst detail pohledu
    def PageStateDetail(self, ID_Login, ID, ID_Page, UrlParameter=None):
        return self._client.service.PageStateDetail({"ID_Login": ID_Login, "ID": ID, "ID_Page": ID_Page, "UrlParameter": UrlParameter})

    # Načíst seznam položek pohledu
    def PageStateItemAll(self, ID_Login, ID, ID_PageState):
        return self._client.service.PageStateItemAll({"ID_Login": ID_Login, "ID": ID, "ID_PageState": ID_PageState})

    # Smazat
    def PageStateItemDelete(self, ID_Login, ID_Page):
        return self._client.service.PageStateItemDelete({"ID_Login": ID_Login, "ID_Page": ID_Page})

    # Upravit pohled
    def PageStateUpdate(self, ID_Login, ID, ID_User, ID_Known, ID_Page, IsDefault, Page=None, DisplayName=None, Data=None):
        return self._client.service.PageStateUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Known": ID_Known, "ID_Page": ID_Page, "IsDefault": IsDefault, "Page": Page, "DisplayName": DisplayName, "Data": Data})

    # Načíst seznam záložek
    def TabAll(self, ID_Login, ID, IsOrderSet, MasterPage=None):
        return self._client.service.TabAll({"ID_Login": ID_Login, "ID": ID, "IsOrderSet": IsOrderSet, "MasterPage": MasterPage})

    # Načíst validační hlášky
    def ValidateAll(self, ID_Login, ID, ProcedureName=None, ID_Action=None):
        return self._client.service.ValidateAll({"ID_Login": ID_Login, "ID": ID, "ProcedureName": ProcedureName, "ID_Action": ID_Action})




import zeep

# Webová služba pro práci s hodnocením kvality
class Evaluation:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Evaluation.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Evaluation.asmx?wsdl')

    # Načíst počty hodnocení po jednotlivých úrovních
    def EvaluationAllDegradationCount(self, ID_Login, Year):
        return self._client.service.EvaluationAllDegradationCount({"ID_Login": ID_Login, "Year": Year})

    # Načíst seznam hodnocení kvality akcí
    def EvaluationAllChild(self, ID_Login, Year, IsUnit):
        return self._client.service.EvaluationAllChild({"ID_Login": ID_Login, "Year": Year, "IsUnit": IsUnit})

    # Grafický pohled - počty hodnocení dané úrovně za posledních 10 let
    def EvaluationAllGraphParticipationYearCompare(self, ID_Login, EvaluationTypeID=None):
        return self._client.service.EvaluationAllGraphParticipationYearCompare({"ID_Login": ID_Login, "EvaluationTypeID": EvaluationTypeID})

    # Grafický pohled - počty hodnocení dané úrovně dle výsledků za posledních 10 let
    def EvaluationAllGraphRatingYearCompare(self, ID_Login, EvaluationTypeID=None):
        return self._client.service.EvaluationAllGraphRatingYearCompare({"ID_Login": ID_Login, "EvaluationTypeID": EvaluationTypeID})

    # Grafický pohled na hodnocení podřízených jednotek - Valašský frgál
    def EvaluationAllGraphSummary(self, ID_Login, ID_EvaluationSubtype, Year, DrawGraph):
        return self._client.service.EvaluationAllGraphSummary({"ID_Login": ID_Login, "ID_EvaluationSubtype": ID_EvaluationSubtype, "Year": Year, "DrawGraph": DrawGraph})

    # Načíst počty hodnocení po jednotlivých úrovních
    def EvaluationAllImprovementCount(self, ID_Login, Year):
        return self._client.service.EvaluationAllImprovementCount({"ID_Login": ID_Login, "Year": Year})

    # Načíst seznam hodnocení kvality akcí
    def EvaluationAllParent(self, ID_Login, Year):
        return self._client.service.EvaluationAllParent({"ID_Login": ID_Login, "Year": Year})

    # Načíst účást HK podřízených jednotek
    def EvaluationAllParticipation(self, ID_Login, Year, EvaluationTypeID=None):
        return self._client.service.EvaluationAllParticipation({"ID_Login": ID_Login, "Year": Year, "EvaluationTypeID": EvaluationTypeID})

    # Načíst účást HK podřízených jednotek
    def EvaluationAllParticipationCompare(self, ID_Login, Year):
        return self._client.service.EvaluationAllParticipationCompare({"ID_Login": ID_Login, "Year": Year})

    # Načíst počty stabilních hodnocení po jednotlivých úrovních
    def EvaluationAllSectionMedian(self, ID_Login, Year, ID_EvaluationSubtype):
        return self._client.service.EvaluationAllSectionMedian({"ID_Login": ID_Login, "Year": Year, "ID_EvaluationSubtype": ID_EvaluationSubtype})

    # Načíst počty stabilních hodnocení po jednotlivých úrovních
    def EvaluationAllStabilityCount(self, ID_Login, Year):
        return self._client.service.EvaluationAllStabilityCount({"ID_Login": ID_Login, "Year": Year})

    # Načíst počty hodnocení po jednotlivých úrovních
    def EvaluationAllTypeCount(self, ID_Login, Year, EvaluationTypeID=None):
        return self._client.service.EvaluationAllTypeCount({"ID_Login": ID_Login, "Year": Year, "EvaluationTypeID": EvaluationTypeID})

    # Načíst seznam kritérii pro oblast hodnocní
    def EvaluationCriteriaAllEvaluation(self, ID_Login, ID_Evaluation, ID_EvaluationSection):
        return self._client.service.EvaluationCriteriaAllEvaluation({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation, "ID_EvaluationSection": ID_EvaluationSection})

    # Načíst srovnání s ostatními
    def EvaluationAllCompare(self, ID_Login, Year, DrawGraph, Culture=None):
        return self._client.service.EvaluationAllCompare({"ID_Login": ID_Login, "Year": Year, "DrawGraph": DrawGraph, "Culture": Culture})

    # Načíst srovnání s ostatními
    def EvaluationDetailCompare(self, ID_Login, ID, DrawGraph, Culture=None):
        return self._client.service.EvaluationDetailCompare({"ID_Login": ID_Login, "ID": ID, "DrawGraph": DrawGraph, "Culture": Culture})

    # Stáhnout všechny exporty hodnocení kvality
    def EvaluationDetailExport(self, ID_Login, ID):
        return self._client.service.EvaluationDetailExport({"ID_Login": ID_Login, "ID": ID})

    # Načíst graf vah oblastí daného hodnocení
    def EvaluationDetailGraphSectionWeight(self, ID_Login, ID, ID_EvaluationSection, SectionColor=None):
        return self._client.service.EvaluationDetailGraphSectionWeight({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSection": ID_EvaluationSection, "SectionColor": SectionColor})

    # Načíst meziroční srovnání
    def EvaluationDetailYearCompare(self, ID_Login, ID, ID_Unit, ID_Event):
        return self._client.service.EvaluationDetailYearCompare({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event})

    # Načíst graf meziroční srovnání
    def EvaluationDetailGraphYearCompare(self, ID_Login, ID, ID_Unit, ID_Event):
        return self._client.service.EvaluationDetailGraphYearCompare({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event})

    # Grafický pohled na hodnocení - Valašský frgál
    def EvaluationGraph(self, DrawGraph, ID_Login, ID):
        return self._client.service.EvaluationGraph({"DrawGraph": DrawGraph, "ID_Login": ID_Login, "ID": ID})

    # Načíst seznam hodnocení kvality
    def EvaluationAll(self, ID_Login, Year, NotExists, IsUnit, ID_EventEducationType, ID_EvaluationState=None, Unit=None, ID_EventType=None):
        return self._client.service.EvaluationAll({"ID_Login": ID_Login, "Year": Year, "NotExists": NotExists, "IsUnit": IsUnit, "ID_EventEducationType": ID_EventEducationType, "ID_EvaluationState": ID_EvaluationState, "Unit": Unit, "ID_EventType": ID_EventType})

    # Načíst seznam hodnocení kvality akcí
    def EvaluationAllPerson(self, ID_Login, Year, IsUnit, NotExists, ID_EventEducationType, ID_EventType=None):
        return self._client.service.EvaluationAllPerson({"ID_Login": ID_Login, "Year": Year, "IsUnit": IsUnit, "NotExists": NotExists, "ID_EventEducationType": ID_EventEducationType, "ID_EventType": ID_EventType})

    # Seznam let, ve kterých je mozne zalozit hodnocení kvality
    def EvaluationAllYearCreate(self, ID_Login, IsUnit, IsEventEducation):
        return self._client.service.EvaluationAllYearCreate({"ID_Login": ID_Login, "IsUnit": IsUnit, "IsEventEducation": IsEventEducation})

    # Načíst seznam odpovědí individuálního hodnocení kvality
    def EvaluationAnswerAllEvaluationPerson(self, ID_Login, ID_EvaluationPerson):
        return self._client.service.EvaluationAnswerAllEvaluationPerson({"ID_Login": ID_Login, "ID_EvaluationPerson": ID_EvaluationPerson})

    # Načíst seznam individuálních hodnocení k základnímu hodnocení
    def EvaluationPersonAllEvaluation(self, ID_Login, ID, ID_Evaluation, ID_Person):
        return self._client.service.EvaluationPersonAllEvaluation({"ID_Login": ID_Login, "ID": ID, "ID_Evaluation": ID_Evaluation, "ID_Person": ID_Person})

    # Založit individuální hodnocení
    def EvaluationPersonInsert(self, ID_Login, ID_Evaluation, ID_Person, ID_Event, ID_EvaluationSubtype, Year):
        return self._client.service.EvaluationPersonInsert({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation, "ID_Person": ID_Person, "ID_Event": ID_Event, "ID_EvaluationSubtype": ID_EvaluationSubtype, "Year": Year})

    # Upravit individuální hodnocení kvality
    def EvaluationPersonUpdate(self, ID_Login, ID, Answers=None):
        return self._client.service.EvaluationPersonUpdate({"ID_Login": ID_Login, "ID": ID, "Answers": Answers})

    # Načíst číselný přehled hodnocení
    def EvaluationSectionAllEvaluation(self, ID_Login, ID_Evaluation):
        return self._client.service.EvaluationSectionAllEvaluation({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation})

    # Načíst graf s váhami bodů vize dané oblasti
    def EvaluationSectionDetailGraphCriteriaWeight(self, ID_Login, ID, ID_Evaluation, GraphColor=None):
        return self._client.service.EvaluationSectionDetailGraphCriteriaWeight({"ID_Login": ID_Login, "ID": ID, "ID_Evaluation": ID_Evaluation, "GraphColor": GraphColor})

    # Načíst číselný přehled hodnocení
    def EvaluationSetAllEvaluation(self, ID_Login, ID_Evaluation):
        return self._client.service.EvaluationSetAllEvaluation({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation})

    # Načíst seznam základních typů hodnocení kvality
    def EvaluationSubtypeAllType(self, ID_Login, EvaluationTypeID=None):
        return self._client.service.EvaluationSubtypeAllType({"ID_Login": ID_Login, "EvaluationTypeID": EvaluationTypeID})

    # Načíst seznam celkových hodnocení
    def RatingAll(self, ID_Login, DisplayName=None):
        return self._client.service.RatingAll({"ID_Login": ID_Login, "DisplayName": DisplayName})

    # Upravit celkové hodnocení
    def RatingUpdate(self, ID_Login, ID, ScoreFrom, ScoreTo, DisplayName=None, Color=None):
        return self._client.service.RatingUpdate({"ID_Login": ID_Login, "ID": ID, "ScoreFrom": ScoreFrom, "ScoreTo": ScoreTo, "DisplayName": DisplayName, "Color": Color})

    # Věřejná sumarizovaná data hodnocení kvality
    def EvaluationSummaryPublic(self, ID_Login, Year, ID_EvaluationSubtype, ID_UnitArray=None, ID_UnitType=None):
        return self._client.service.EvaluationSummaryPublic({"ID_Login": ID_Login, "Year": Year, "ID_EvaluationSubtype": ID_EvaluationSubtype, "ID_UnitArray": ID_UnitArray, "ID_UnitType": ID_UnitType})

    # Detailní výsledek hodnocení kvality
    def EvaluationAnswerAllResult(self, ID_Login, ID_Evaluation):
        return self._client.service.EvaluationAnswerAllResult({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation})

    # Založit hodnocení kvality akce
    def EvaluationInsertEvent(self, ID_Login, ID, ID_EvaluationSubtype, EvaluationCount, ID_EvaluationVersion, ID_Unit, ID_Event, ID_EventParent, Year, DateLastUpdate, ID_PersonClose, DateClose, Score, ID_EvaluationRating, HideDetail, EvaluationSubtype=None, Description=None, EvaluationVersion=None, Unit=None, RegistrationNumber=None, Event=None, ID_EvaluationState=None, EvaluationState=None, Note=None, NoteParent=None, PersonClose=None, EvaluationRating=None, Color=None, ID_UnitType=None, UnitType=None):
        return self._client.service.EvaluationInsertEvent({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSubtype": ID_EvaluationSubtype, "EvaluationCount": EvaluationCount, "ID_EvaluationVersion": ID_EvaluationVersion, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_EventParent": ID_EventParent, "Year": Year, "DateLastUpdate": DateLastUpdate, "ID_PersonClose": ID_PersonClose, "DateClose": DateClose, "Score": Score, "ID_EvaluationRating": ID_EvaluationRating, "HideDetail": HideDetail, "EvaluationSubtype": EvaluationSubtype, "Description": Description, "EvaluationVersion": EvaluationVersion, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Event": Event, "ID_EvaluationState": ID_EvaluationState, "EvaluationState": EvaluationState, "Note": Note, "NoteParent": NoteParent, "PersonClose": PersonClose, "EvaluationRating": EvaluationRating, "Color": Color, "ID_UnitType": ID_UnitType, "UnitType": UnitType})

    # Načíst seznam hodnocení kvality akcí
    def EvaluationAllEvent(self, ID_Login, Year, NotExists, ID_EvaluationState=None, Unit=None, ID_EventType=None):
        return self._client.service.EvaluationAllEvent({"ID_Login": ID_Login, "Year": Year, "NotExists": NotExists, "ID_EvaluationState": ID_EvaluationState, "Unit": Unit, "ID_EventType": ID_EventType})

    # Načíst seznam akcí posunů
    def EvaluationAnswerAllShift(self, ID_Login, ID_Evaluation, ID_EvaluationSection, Count, RowMin):
        return self._client.service.EvaluationAnswerAllShift({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation, "ID_EvaluationSection": ID_EvaluationSection, "Count": Count, "RowMin": RowMin})

    # Výsledky hodnocení kvality pohled na regiony
    def EvaluationSummaryRegion(self, ID_Login, Year, ID_EvaluationSubtype, ID_UnitType=None):
        return self._client.service.EvaluationSummaryRegion({"ID_Login": ID_Login, "Year": Year, "ID_EvaluationSubtype": ID_EvaluationSubtype, "ID_UnitType": ID_UnitType})

    # Otevřít hodnocení
    def EvaluationUpdateOpen(self, ID_Login, ID, ID_EvaluationSubtype, EvaluationCount, ID_EvaluationVersion, ID_Unit, ID_Event, ID_EventParent, Year, DateLastUpdate, ID_PersonClose, DateClose, Score, ID_EvaluationRating, HideDetail, EvaluationSubtype=None, Description=None, EvaluationVersion=None, Unit=None, RegistrationNumber=None, Event=None, ID_EvaluationState=None, EvaluationState=None, Note=None, NoteParent=None, PersonClose=None, EvaluationRating=None, Color=None, ID_UnitType=None, UnitType=None):
        return self._client.service.EvaluationUpdateOpen({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSubtype": ID_EvaluationSubtype, "EvaluationCount": EvaluationCount, "ID_EvaluationVersion": ID_EvaluationVersion, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_EventParent": ID_EventParent, "Year": Year, "DateLastUpdate": DateLastUpdate, "ID_PersonClose": ID_PersonClose, "DateClose": DateClose, "Score": Score, "ID_EvaluationRating": ID_EvaluationRating, "HideDetail": HideDetail, "EvaluationSubtype": EvaluationSubtype, "Description": Description, "EvaluationVersion": EvaluationVersion, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Event": Event, "ID_EvaluationState": ID_EvaluationState, "EvaluationState": EvaluationState, "Note": Note, "NoteParent": NoteParent, "PersonClose": PersonClose, "EvaluationRating": EvaluationRating, "Color": Color, "ID_UnitType": ID_UnitType, "UnitType": UnitType})

    # Uzavřít hodnocení
    def EvaluationUpdateClose(self, ID_Login, ID, ID_EvaluationSubtype, EvaluationCount, ID_EvaluationVersion, ID_Unit, ID_Event, ID_EventParent, Year, DateLastUpdate, ID_PersonClose, DateClose, Score, ID_EvaluationRating, HideDetail, EvaluationSubtype=None, Description=None, EvaluationVersion=None, Unit=None, RegistrationNumber=None, Event=None, ID_EvaluationState=None, EvaluationState=None, Note=None, NoteParent=None, PersonClose=None, EvaluationRating=None, Color=None, ID_UnitType=None, UnitType=None):
        return self._client.service.EvaluationUpdateClose({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSubtype": ID_EvaluationSubtype, "EvaluationCount": EvaluationCount, "ID_EvaluationVersion": ID_EvaluationVersion, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_EventParent": ID_EventParent, "Year": Year, "DateLastUpdate": DateLastUpdate, "ID_PersonClose": ID_PersonClose, "DateClose": DateClose, "Score": Score, "ID_EvaluationRating": ID_EvaluationRating, "HideDetail": HideDetail, "EvaluationSubtype": EvaluationSubtype, "Description": Description, "EvaluationVersion": EvaluationVersion, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Event": Event, "ID_EvaluationState": ID_EvaluationState, "EvaluationState": EvaluationState, "Note": Note, "NoteParent": NoteParent, "PersonClose": PersonClose, "EvaluationRating": EvaluationRating, "Color": Color, "ID_UnitType": ID_UnitType, "UnitType": UnitType})

    # Seznam let, ve kterých jsou hodnocení kvality k dispozici
    def EvaluationAllYear(self, ID_Login):
        return self._client.service.EvaluationAllYear({"ID_Login": ID_Login})

    # Načíst seznam hodnocení kvality jednoty
    def EvaluationAllUnit(self, ID_Login, Year, NotExists, ID_EvaluationState=None, Unit=None):
        return self._client.service.EvaluationAllUnit({"ID_Login": ID_Login, "Year": Year, "NotExists": NotExists, "ID_EvaluationState": ID_EvaluationState, "Unit": Unit})

    # Načíst seznam odpovědí hodnocení kvality
    def EvaluationAnswerAll(self, ID_Login, ID_Evaluation, EvaluationPersonCount):
        return self._client.service.EvaluationAnswerAll({"ID_Login": ID_Login, "ID_Evaluation": ID_Evaluation, "EvaluationPersonCount": EvaluationPersonCount})

    # Načíst detail hodnocení kvality
    def EvaluationDetail(self, ID_Login, ID, ID_EvaluationPerson):
        return self._client.service.EvaluationDetail({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationPerson": ID_EvaluationPerson})

    # Založit hodnocení kvality
    def EvaluationInsert(self, ID_Login, ID, ID_EvaluationSubtype, EvaluationCount, ID_EvaluationVersion, ID_Unit, ID_Event, ID_EventParent, Year, DateLastUpdate, ID_PersonClose, DateClose, Score, ID_EvaluationRating, HideDetail, EvaluationSubtype=None, Description=None, EvaluationVersion=None, Unit=None, RegistrationNumber=None, Event=None, ID_EvaluationState=None, EvaluationState=None, Note=None, NoteParent=None, PersonClose=None, EvaluationRating=None, Color=None, ID_UnitType=None, UnitType=None):
        return self._client.service.EvaluationInsert({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSubtype": ID_EvaluationSubtype, "EvaluationCount": EvaluationCount, "ID_EvaluationVersion": ID_EvaluationVersion, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_EventParent": ID_EventParent, "Year": Year, "DateLastUpdate": DateLastUpdate, "ID_PersonClose": ID_PersonClose, "DateClose": DateClose, "Score": Score, "ID_EvaluationRating": ID_EvaluationRating, "HideDetail": HideDetail, "EvaluationSubtype": EvaluationSubtype, "Description": Description, "EvaluationVersion": EvaluationVersion, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Event": Event, "ID_EvaluationState": ID_EvaluationState, "EvaluationState": EvaluationState, "Note": Note, "NoteParent": NoteParent, "PersonClose": PersonClose, "EvaluationRating": EvaluationRating, "Color": Color, "ID_UnitType": ID_UnitType, "UnitType": UnitType})

    # Načíst seznam celkových číselných hodnocení
    def EvaluationRatingAll(self, ID_Login, ID_EvaluationVersion, DisplayName=None):
        return self._client.service.EvaluationRatingAll({"ID_Login": ID_Login, "ID_EvaluationVersion": ID_EvaluationVersion, "DisplayName": DisplayName})

    # Smazat celkové číselné hodnocení
    def EvaluationRatingDelete(self, ID_Login, ID):
        return self._client.service.EvaluationRatingDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit celkové číselné hodnocení
    def EvaluationRatingInsert(self, ID_Login, ID, ID_EvaluationVersion, ScoreFrom, ScoreTo, DisplayName=None):
        return self._client.service.EvaluationRatingInsert({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationVersion": ID_EvaluationVersion, "ScoreFrom": ScoreFrom, "ScoreTo": ScoreTo, "DisplayName": DisplayName})

    # Upravit celkové ?íselné hodnocení
    def EvaluationRatingUpdate(self, ID_Login, ID, ID_EvaluationVersion, ScoreFrom, ScoreTo, DisplayName=None):
        return self._client.service.EvaluationRatingUpdate({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationVersion": ID_EvaluationVersion, "ScoreFrom": ScoreFrom, "ScoreTo": ScoreTo, "DisplayName": DisplayName})

    # Načíst seznam stavů hodnocení kvality
    def EvaluationStateAll(self, ID_Login, DisplayName=None):
        return self._client.service.EvaluationStateAll({"ID_Login": ID_Login, "DisplayName": DisplayName})

    # Upravit hodnocení kvality
    def EvaluationUpdate(self, ID_Login, ID, Answers=None):
        return self._client.service.EvaluationUpdate({"ID_Login": ID_Login, "ID": ID, "Answers": Answers})

    # Otevřít publikovanou verzi typu pro úpravy
    def EvaluationVersionInsertEvaluationSubtype(self, ID_Login, ID_EvaluationSubtype):
        return self._client.service.EvaluationVersionInsertEvaluationSubtype({"ID_Login": ID_Login, "ID_EvaluationSubtype": ID_EvaluationSubtype})

    # Otevřít publikovanou verzi typu pro úpravy
    def EvaluationSubtypeUpdateOpen(self, ID_Login, ID):
        return self._client.service.EvaluationSubtypeUpdateOpen({"ID_Login": ID_Login, "ID": ID})

    # Upravit typ hodnocení kvality
    def EvaluationSubtypeUpdate(self, ID_Login, ID, ID_EventEducationType, ID_EvaluationVersion, DisplayName=None, ID_UnitType=None, UnitType=None, ID_EventType=None, EventType=None, EventEducationType=None, Description=None, Note=None):
        return self._client.service.EvaluationSubtypeUpdate({"ID_Login": ID_Login, "ID": ID, "ID_EventEducationType": ID_EventEducationType, "ID_EvaluationVersion": ID_EvaluationVersion, "DisplayName": DisplayName, "ID_UnitType": ID_UnitType, "UnitType": UnitType, "ID_EventType": ID_EventType, "EventType": EventType, "EventEducationType": EventEducationType, "Description": Description, "Note": Note})

    # Načíst seznam kritérií hodnocení
    def EvaluationCriteriaAll(self, ID_Login, ID_EvaluationSet, DisplayName=None):
        return self._client.service.EvaluationCriteriaAll({"ID_Login": ID_Login, "ID_EvaluationSet": ID_EvaluationSet, "DisplayName": DisplayName})

    # Smazat kritérium hodnocení
    def EvaluationCriteriaDelete(self, ID_Login, ID):
        return self._client.service.EvaluationCriteriaDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail kritéria hodnocení
    def EvaluationCriteriaDetail(self, ID_Login, ID):
        return self._client.service.EvaluationCriteriaDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit kritérium hodnocení
    def EvaluationCriteriaInsert(self, ID_Login, ID, ID_EvaluationSet, Order, Weight, EvaluationSet=None, DisplayName=None, Answer1=None, Shift1=None, Answer2=None, Shift2=None, Answer3=None, Shift3=None, Answer4=None, Note=None, ID_EvaluationVersionState=None, EvaluationVersionState=None):
        return self._client.service.EvaluationCriteriaInsert({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSet": ID_EvaluationSet, "Order": Order, "Weight": Weight, "EvaluationSet": EvaluationSet, "DisplayName": DisplayName, "Answer1": Answer1, "Shift1": Shift1, "Answer2": Answer2, "Shift2": Shift2, "Answer3": Answer3, "Shift3": Shift3, "Answer4": Answer4, "Note": Note, "ID_EvaluationVersionState": ID_EvaluationVersionState, "EvaluationVersionState": EvaluationVersionState})

    # Upravit kritérium hodnocení
    def EvaluationCriteriaUpdate(self, ID_Login, ID, ID_EvaluationSet, Order, Weight, EvaluationSet=None, DisplayName=None, Answer1=None, Shift1=None, Answer2=None, Shift2=None, Answer3=None, Shift3=None, Answer4=None, Note=None, ID_EvaluationVersionState=None, EvaluationVersionState=None):
        return self._client.service.EvaluationCriteriaUpdate({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSet": ID_EvaluationSet, "Order": Order, "Weight": Weight, "EvaluationSet": EvaluationSet, "DisplayName": DisplayName, "Answer1": Answer1, "Shift1": Shift1, "Answer2": Answer2, "Shift2": Shift2, "Answer3": Answer3, "Shift3": Shift3, "Answer4": Answer4, "Note": Note, "ID_EvaluationVersionState": ID_EvaluationVersionState, "EvaluationVersionState": EvaluationVersionState})

    # Smazat oblast kvality
    def EvaluationSectionDelete(self, ID_Login, ID):
        return self._client.service.EvaluationSectionDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail oblasti kvality
    def EvaluationSectionDetail(self, ID_Login, ID):
        return self._client.service.EvaluationSectionDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit oblast kvality
    def EvaluationSectionInsert(self, ID_Login, ID, ID_EvaluationVersion, Order, Weight, ID_EvaluationSubtype, DisplayName=None, Note=None, Description=None, EvaluationSubtype=None, Color=None):
        return self._client.service.EvaluationSectionInsert({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationVersion": ID_EvaluationVersion, "Order": Order, "Weight": Weight, "ID_EvaluationSubtype": ID_EvaluationSubtype, "DisplayName": DisplayName, "Note": Note, "Description": Description, "EvaluationSubtype": EvaluationSubtype, "Color": Color})

    # Upravit oblast kvality
    def EvaluationSectionUpdate(self, ID_Login, ID, ID_EvaluationVersion, Order, Weight, ID_EvaluationSubtype, DisplayName=None, Note=None, Description=None, EvaluationSubtype=None, Color=None):
        return self._client.service.EvaluationSectionUpdate({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationVersion": ID_EvaluationVersion, "Order": Order, "Weight": Weight, "ID_EvaluationSubtype": ID_EvaluationSubtype, "DisplayName": DisplayName, "Note": Note, "Description": Description, "EvaluationSubtype": EvaluationSubtype, "Color": Color})

    # Načíst seznam skupin kritérií
    def EvaluationSetAll(self, ID_Login, ID_EvaluationVersion, DisplayName=None):
        return self._client.service.EvaluationSetAll({"ID_Login": ID_Login, "ID_EvaluationVersion": ID_EvaluationVersion, "DisplayName": DisplayName})

    # Smazat skupinu kritérií
    def EvaluationSetDelete(self, ID_Login, ID):
        return self._client.service.EvaluationSetDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail bodu vize
    def EvaluationSetDetail(self, ID_Login, ID):
        return self._client.service.EvaluationSetDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit skupinu kritérií
    def EvaluationSetInsert(self, ID_Login, ID, ID_EvaluationSection, Order, Weight, ID_EvaluationSubtype, EvaluationSection=None, DisplayName=None, Note=None, Description=None):
        return self._client.service.EvaluationSetInsert({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSection": ID_EvaluationSection, "Order": Order, "Weight": Weight, "ID_EvaluationSubtype": ID_EvaluationSubtype, "EvaluationSection": EvaluationSection, "DisplayName": DisplayName, "Note": Note, "Description": Description})

    # Upravit skupinu kritérií
    def EvaluationSetUpdate(self, ID_Login, ID, ID_EvaluationSection, Order, Weight, ID_EvaluationSubtype, EvaluationSection=None, DisplayName=None, Note=None, Description=None):
        return self._client.service.EvaluationSetUpdate({"ID_Login": ID_Login, "ID": ID, "ID_EvaluationSection": ID_EvaluationSection, "Order": Order, "Weight": Weight, "ID_EvaluationSubtype": ID_EvaluationSubtype, "EvaluationSection": EvaluationSection, "DisplayName": DisplayName, "Note": Note, "Description": Description})

    # Načíst seznam typů hodnocení kvality
    def EvaluationSubtypeAll(self, ID_Login, ID_EvaluationVersion, IsEvent, IsPublished, DisplayName=None, ID_UnitType=None, ID_EventType=None):
        return self._client.service.EvaluationSubtypeAll({"ID_Login": ID_Login, "ID_EvaluationVersion": ID_EvaluationVersion, "IsEvent": IsEvent, "IsPublished": IsPublished, "DisplayName": DisplayName, "ID_UnitType": ID_UnitType, "ID_EventType": ID_EventType})

    # Smazat typ hodnocení kvality
    def EvaluationSubtypeDelete(self, ID_Login, ID):
        return self._client.service.EvaluationSubtypeDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail typu hodnocení kvality
    def EvaluationSubtypeDetail(self, ID_Login, ID):
        return self._client.service.EvaluationSubtypeDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit typ hodnocení kvality
    def EvaluationSubtypeInsert(self, ID_Login, ID, ID_EventEducationType, ID_EvaluationVersion, DisplayName=None, ID_UnitType=None, UnitType=None, ID_EventType=None, EventType=None, EventEducationType=None, Description=None, Note=None):
        return self._client.service.EvaluationSubtypeInsert({"ID_Login": ID_Login, "ID": ID, "ID_EventEducationType": ID_EventEducationType, "ID_EvaluationVersion": ID_EvaluationVersion, "DisplayName": DisplayName, "ID_UnitType": ID_UnitType, "UnitType": UnitType, "ID_EventType": ID_EventType, "EventType": EventType, "EventEducationType": EventEducationType, "Description": Description, "Note": Note})

    # Publikovat rozpracovanou verzi typu
    def EvaluationSubtypeUpdatePublish(self, ID_Login, ID):
        return self._client.service.EvaluationSubtypeUpdatePublish({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam verzí typu hodnocení kvality
    def EvaluationVersionAll(self, ID_Login, ID_EvaluationSubtype, ID_EvaluationVersionState=None):
        return self._client.service.EvaluationVersionAll({"ID_Login": ID_Login, "ID_EvaluationSubtype": ID_EvaluationSubtype, "ID_EvaluationVersionState": ID_EvaluationVersionState})

    # Přepočítat výsledky hodnocení kvality
    def EvaluationVersionUpdateCache(self, ID_Login, ID):
        return self._client.service.EvaluationVersionUpdateCache({"ID_Login": ID_Login, "ID": ID})

